@@ -1,7 +1,5 @@
 pub mod abstract_webhook_payload;
 pub use self::abstract_webhook_payload::AbstractWebhookPayload;
-pub mod alias;
-pub use self::alias::Alias;
 pub mod alias_dto;
 pub use self::alias_dto::AliasDto;
 pub mod alias_projection;
@@ -82,6 +80,8 @@ pub mod email_preview;
 pub use self::email_preview::EmailPreview;
 pub mod email_projection;
 pub use self::email_projection::EmailProjection;
+pub mod email_recipients;
+pub use self::email_recipients::EmailRecipients;
 pub mod email_text_lines_result;
 pub use self::email_text_lines_result::EmailTextLinesResult;
 pub mod email_verification_result;
@@ -174,6 +174,8 @@ pub mod page_thread_projection;
 pub use self::page_thread_projection::PageThreadProjection;
 pub mod page_tracking_pixel_projection;
 pub use self::page_tracking_pixel_projection::PageTrackingPixelProjection;
+pub mod page_unknown_missed_email_projection;
+pub use self::page_unknown_missed_email_projection::PageUnknownMissedEmailProjection;
 pub mod page_webhook_projection;
 pub use self::page_webhook_projection::PageWebhookProjection;
 pub mod page_webhook_result;
@@ -182,12 +184,16 @@ pub mod pageable;
 pub use self::pageable::Pageable;
 pub mod raw_email_json;
 pub use self::raw_email_json::RawEmailJson;
+pub mod recipient;
+pub use self::recipient::Recipient;
 pub mod reply_to_alias_email_options;
 pub use self::reply_to_alias_email_options::ReplyToAliasEmailOptions;
 pub mod reply_to_email_options;
 pub use self::reply_to_email_options::ReplyToEmailOptions;
 pub mod send_email_options;
 pub use self::send_email_options::SendEmailOptions;
+pub mod sender;
+pub use self::sender::Sender;
 pub mod sent_email_dto;
 pub use self::sent_email_dto::SentEmailDto;
 pub mod sent_email_projection;
@@ -214,6 +220,8 @@ pub mod tracking_pixel_dto;
 pub use self::tracking_pixel_dto::TrackingPixelDto;
 pub mod tracking_pixel_projection;
 pub use self::tracking_pixel_projection::TrackingPixelProjection;
+pub mod unknown_missed_email_projection;
+pub use self::unknown_missed_email_projection::UnknownMissedEmailProjection;
 pub mod unread_count;
 pub use self::unread_count::UnreadCount;
 pub mod update_alias_options;
@@ -238,6 +246,8 @@ pub mod webhook_dto;
 pub use self::webhook_dto::WebhookDto;
 pub mod webhook_email_opened_payload;
 pub use self::webhook_email_opened_payload::WebhookEmailOpenedPayload;
+pub mod webhook_email_read_payload;
+pub use self::webhook_email_read_payload::WebhookEmailReadPayload;
 pub mod webhook_new_attachment_payload;
 pub use self::webhook_new_attachment_payload::WebhookNewAttachmentPayload;
 pub mod webhook_new_contact_payload;
@@ -246,8 +256,10 @@ pub mod webhook_new_email_payload;
 pub use self::webhook_new_email_payload::WebhookNewEmailPayload;
 pub mod webhook_projection;
 pub use self::webhook_projection::WebhookProjection;
-pub mod webhook_result_entity;
-pub use self::webhook_result_entity::WebhookResultEntity;
+pub mod webhook_redrive_result;
+pub use self::webhook_redrive_result::WebhookRedriveResult;
+pub mod webhook_result_dto;
+pub use self::webhook_result_dto::WebhookResultDto;
 pub mod webhook_test_request;
 pub use self::webhook_test_request::WebhookTestRequest;
 pub mod webhook_test_response;
